#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['math_131_numerics']

package_data = \
{'': ['*']}

setup(name='math_131_numerics',
      version='0.0.2',
      description='Package including standard numerical methods taught in numerics class at UC',
      author='Camille Carvalho',
      author_email='ccarvalho3@ucmerced.edu',
      url='https://www.github.com/carvalhocamille/math_131_numerics',
      packages=packages,
      package_data=package_data,
     )
